*===============================================================================
* File name: 		1cc_CIT_Clean.do
* 
* Description:		This do-file creates CIT_clean.dta dataset, which 
*					contains corporate income tax information and is 
*					used as intermediate dataset in the 1c_undistributedprofits 
*					do file.
*
* Input:  					
*					$databases/Inputs/RawTaxData/ISR_PJ_v3.dta
*
* Output:
*					$databases/Output/Auxiliary/CIT_clean.dta
*===============================================================================

use "$databases/Inputs/RawTaxData/ISR_PJ_v3.dta", clear

drop tamaño_ot_2023
rename anio year

gsort id year
by id year: gen N = _N

/* Check if id-year uniquely identify each entity */
isid id year

// foreach var of varlist ingresos_no_grav-total_deduc_del_ejerc	{
// 	replace `var' = 0 if `var' == .
// }

/* Check dataset */
desc, s
tab year

**Defining key variables


*isid declaracion // not a unique ID
bys declaracion: gen Nd=_N
tab Nd
order Nd, a(declaracion)
sort declaracion

* FLAG. We have the same declaracion number assigned to different year-ID pairs.
* Note. Variables' values are different despite this issue. Seems to not being important.

/* Organize dataset */
sort id year

/* Defining key variables */

*Before 2005, with paper versions a lot of taxpayers did not file cost variable. So we use final resultados;
*This yields the same results in recent years but is the correct variable for older declarations
gen double resultado_ejercicio = total_ingresos_resul_ejercicio - total_deduc_del_ejerc  //TAXABLE PROFIT
gen double taxable_profit 	   = resultado_del_ejercicio - resul_ejer_perdida 

/* Check variables */
summ total_ingresos_resul_ejercicio total_deduc_del_ejerc resultado_del_ejercicio resul_ejer_perdida
* FLAG. Most of resul_ejer_perdida values are either 0 or positive. Two of them are already negative,
* so for these two cases we are "increasing" the taxable profits.
* See IDs 816123, year 2003 and 816122, year 2003.

/* Compare resultado_ejercicio (made by us) and resultado_del_ejercicio (from the dataset) */
order resultado_ejercicio total_deduc_del_ejerc, a(resultado_del_ejercicio)

*Total profit including non-taxable income
gen double total_profit = taxable_profit + (ingresos_no_grav - cyg_total_gastos_gastos_vnd)
gen double turnover     = total_ingresos_resul_ejercicio + ingresos_no_grav

/* Check variables */
summ ingresos_no_grav cyg_total_gastos_gastos_vnd
* FLAG. One value of ingresos_no_grav is negative.

****************************************************************************************************
********************  TAX VARIABLES - ALL REGIMES AND EXEMPTIONS ***********************************
****************************************************************************************************

/**** Variable of due taxes*/
gen double imp_segun_tarifa_renta_alt	   = 0.25*base_impon_rta_neta_grav						

gen double  profit_rate_imponible = base_impon_rta_neta_grav/taxable_profit				//Profit rate using "tax base" variable *****************
*gen double  taxable_inc_rate      = taxable_income/total_ingresos_resul_ejercicio		//Profit rate using created profit measure *****************

*Minimum Tax
gen porcentaje_ing_brutos_correct = porcentaje_ing_brutos
replace porcentaje_ing_brutos_correct = 0 if year == 2013
replace porcentaje_ing_brutos_correct = 0 if base_impon_rta_neta_grav <=0 

gen max_ISR_IM = max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta_alt)	//Maximum between (MinimumTax, LinearIncomeTax)
gen max_AS = max_ISR_IM + imp_segun_tarifa_aport_solid							//Add solidarity tax

/* Check variables */
summ imp_segun_tarifa_renta_alt base_impon_rta_neta_grav profit_rate_imponible porcentaje_ing_brutos porcentaje_ing_brutos_correct imp_segun_tarifa_aport_solid

*Variable indicating which of the taxes is "binding"
gen causa_impuesto = .
replace causa_impuesto = 0 if 	max(max_AS, imp_segun_tarifa_activo_neto) == 0
replace causa_impuesto = 1 if 	max(max_AS, imp_segun_tarifa_activo_neto) == max_AS & ///
								max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta_alt) == imp_segun_tarifa_renta_alt	& ///
								max(max_AS, imp_segun_tarifa_activo_neto) > 0
replace causa_impuesto = 2 if 	max(max_AS, imp_segun_tarifa_activo_neto) == imp_segun_tarifa_activo_neto & ///
								max(max_AS, imp_segun_tarifa_activo_neto) > 0
replace causa_impuesto = 3 if 	max(max_AS, imp_segun_tarifa_activo_neto) == max_AS & ///
								max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta_alt) == porcentaje_ing_brutos_correct & ///
								max(max_AS, imp_segun_tarifa_activo_neto) > 0
								
lab def causa_impuesto 0"Ninguno" 1"Renta" 2"Activo Neto" 3"Impuesto Mínimo"
lab val causa_impuesto causa_impuesto

tab causa_impuesto, gen(causa_impuesto_)

gen double impuesto_causado = .
replace impuesto_causado = 0 		 						if causa_impuesto == 0
replace impuesto_causado = max_AS 							if causa_impuesto == 1
replace impuesto_causado = imp_segun_tarifa_activo_neto 	if causa_impuesto == 2
replace impuesto_causado = max_AS 							if causa_impuesto == 3
label var impuesto_causado "Impuesto causado real"

*Variable indicando que base esta causando
clonevar tax_type = causa_impuesto
lab def tax_type 0"Not taxed" 1"Income Tax" 2"Asset Tax" 3"Minimum Tax", replace
lab val tax_type tax_type

/* Re-create variables of causa impuesto */
gen max_tax=max(max_AS,imp_segun_tarifa_activo_neto,porcentaje_ing_brutos_correct)
order max_tax, a(impuesto_causado)
count if max_tax!=impuesto_causado

order max_AS imp_segun_tarifa_activo_neto porcentaje_ing_brutos_correct causa_impuesto impuesto_causado max_tax, a(year)

/* Check variables */
summ cre_importe_exo_red_rta cre_importe_exo_red_act_neto cre_importe_exo_aport_soli

***Exonerados***
egen cre_importe_exo = rowtotal(cre_importe_exo_red_rta cre_importe_exo_red_act_neto cre_importe_exo_aport_soli), missing

gen ratio_exoneracion = 0
replace ratio_exoneracion = (cre_importe_exo_red_rta + cre_importe_exo_aport_soli)/(imp_segun_tarifa_renta + ///
							imp_segun_tarifa_aport_solid) if (causa_impuesto==1 | causa_impuesto==3) 
replace ratio_exoneracion = cre_importe_exo_red_act_neto/imp_segun_tarifa_activo_neto if causa_impuesto==2	

gen exonerado = (ratio_exoneracion > 0.9 & !missing(ratio_exoneracion))

**Discount exemption credits from taxes due
replace impuesto_causado = max(0,impuesto_causado - cre_importe_exo_red_rta - cre_importe_exo_aport_soli) if (causa_impuesto==1 | causa_impuesto==3) 
replace impuesto_causado = max(0,impuesto_causado - cre_importe_exo_red_act_neto) if causa_impuesto==2	


***Effective tax rates

gen effective_rate     = impuesto_causado/taxable_profit			//Original tax liability as share of gross revenue
replace effective_rate = 0 if taxable_profit < 0

gen effective_rate_profit     = impuesto_causado/(total_profit)		//Original tax liability as share of gross revenue
replace effective_rate_profit = 0 if total_profit < 0

gquantiles percentile_turnover_cit = turnover, xtile nquantiles(100) by(year)

keep id year turnover total_ingresos_resul_ejercicio total_deduc_del_ejerc resultado_ejercicio taxable_profit total_profit ///
		causa_impuesto impuesto_causado ingresos_no_grav effective_rate effective_rate_profit cyg_total_gastos_gastos_vnd exonerado ///
		percentile_turnover_cit

save "$databases/Output/Auxiliary/CIT_clean.dta", replace
