*===============================================================================
* File name: 		1d_Inequality_Clean_loop.do
* 
* Description:		This do-file creates the TaxData_`year'.dta datasets for the 
*					2011-2020 period, which contain inequality measures related 
*					data and are used as intermediate datasets in the 
*					2d_inequality_createvars_loop do file.
*
* Input:  					
*					$databases/Inputs/RawTaxData/MostUpdated_Apr23/`year'.csv
*					$databases/Output/CleanTaxData/CapitalGains.dta
*					$databases/Output/CleanTaxData/RentalIncome.dta
*					$databases/Output/Auxiliary/UndistributedProfits_individual.dta
*					$databases/Output/CleanTaxData/Gender_age_dataset.dta
*
* Output:
*					$databases/Output/CleanTaxData/TaxData_`year'.dta
*===============================================================================

set seed 521685

* Open csv and save as stata
quietly {

foreach year of numlist 2011/2020 {
	
	
	di in red "Loading taxdata `year'"
	
	import delimited "$databases/Inputs/RawTaxData/MostUpdated_Apr23/`year'.csv", clear encoding("utf-8")
		
		* Check dataset
		desc, s
		
		* Stable duplicate drop
		drop if id == .
		// 0 dropped
		
		gen random = runiform()
		isid id random, sort //stable-sorting by taxpayer_id and year
		by id (random): drop if _n > 1 //removing all obs other than the first
		// no duplicated obs in terms of ID
		
		// duplicates drop id, force
		di in red "Duplicates droped: `r(N_drop)'"
		
		*Drop when taxpayer has invalid number which ends up collecting incorrect withholding
		capture confirm var ot_irregular
		if c(rc) == 111 { // VARIABLE NOT FOUND
			gen ot_irregular = 0
		}
		drop if ot_irregular == 1
		di in red "Incorrect taxpayer IDs droped: `r(N_drop)'"
		
		gen year  = `year'
		
		if `year' == 2020 {
			rename id_seccin id_sección
		}
		
		if inlist(`year',2019,2020) {
			gen tamao_ot = ""
			rename id_sección id_seccin
			drop totalutilidadgcneto
			drop ingreanualalquilerhab

		}
		else if `year' == 2018 {
			drop if id == .						//Drop 33 observations with income but invalid IDs (not active, non existent in other years)
			rename tamanio_ot tamao_ot
			rename id_sección id_seccin
			drop totalutilidadgcneto
			drop ingreanualalquilerhab
		}
		
		merge 1:1 id year using "$databases/Output/CleanTaxData/CapitalGains.dta"			//Merging rental income data
		drop if (_merge == 2 & year != `year')
		drop _merge
		
		merge 1:1 id year using "$databases/Output/CleanTaxData/RentalIncome.dta"			//merging capital gains data
		drop if (_merge == 2 & year != `year')
		drop _merge
		
		merge 1:1  id year using "$databases/Output/Auxiliary/UndistributedProfits_individual.dta"   //Merging undistributed profits
		drop if (_merge == 2 & year != `year')
		drop _merge

		*Changing string variables to numeric + labels
		foreach var of varlist departamento municipio tipo_ot tamao_ot id_seccin d_macro_actividad d_division d_grupo d_clase {
			encode `var', gen(`var'_num)
			drop `var'
		}

		rename (departamento_num municipio_num tipo_ot_num tamao_ot_num dmr_111_ingreso_anual ) ///
			  (djisr_chr_departamento djisr_chr_municipio djisr_chr_tipo djisr_chr_size dmr_111 )

		rename (id_division id_grupo id_clase id_seccin_num d_macro_actividad_num d_division_num d_grupo_num d_clase_num) ///
				(act_div_code act_grupo_code act_class_code act_section act_macro act_division acg_grupo act_class)
				
		rename (atc siafi dmc dmr_135 export_aduana total_informado_terceros) (tpi_atc tpi_siafi tpi_dmc tpi_dmr_135 ///
				tpi_exports tpi_total)
		 
		if inlist(`year',2019,2020) {
			gen presenta_djisr = (ingre_acti_mercantiles != .)
		}
		
		if `year' == 2018 {	
		
			rename ( creretenanticipoirs creretenart50leyisr creretenfuenteasal ingresosnetosnograv totaldeducresulejer totalinggravresulejer ///
					 impuestoseguntarifa) ///
					( djisr_cred_anticipo djisr_cred_art50 djisr_cred_wage djisr_nontaxable_income djisr_deductions djisr_gross_income ///
					 impuesto_segun_tarifa)
			
			rename (ingresosactimercantiles ingresoshonoraprof ingresosinternobanc ingresosporactiart20 ingresosporalquileres ///
				ingresosporservicios ingresossueldossalaboni otrosingregravados) ///
				(djisr_income_commercial djisr_income_honorario djisr_income_interest ///
				djisr_income_art20 djisr_income_rents djisr_income_services djisr_income_wages djisr_income_other)
			rename (deducactimercantiles deduchonorariosprof deducporinternobanc deducporactart20 deducporalquileres ///
				 deducporservicios deducsueldossalboni deducotrosingregrav ) ///
				(djisr_deduction_commercial djisr_deduction_honorario djisr_deduction_interest ///
				djisr_deduction_art20 djisr_deduction_rents djisr_deduction_services djisr_deduction_wages djisr_deduction_other)
			
			gen djisr_dummy_filed = (djisr_gross_income != .)							//create filing dummy
		}
		
		
		else {
			rename (cre_reten_anticipo_irs cre_reten_art50_ley_isr cre_reten_fuente_asal ingre_netos_no_grav total_deduc_resul_ejer ///
				total_ing_grav_resul_ejer  presenta_djisr) (djisr_cred_anticipo djisr_cred_art50 djisr_cred_wage djisr_nontaxable_income ///
				djisr_deductions djisr_gross_income djisr_dummy_filed)
			 
			rename (ingre_acti_mercantiles ingre_honora_prof ingre_inter_no_banc ingre_por_acti_art20 ingre_por_alquileres ///
					ingre_por_servicios ingre_sueldos_sala_boni otros_ingre_gravados) (djisr_income_commercial djisr_income_honorario djisr_income_interest ///
					djisr_income_art20 djisr_income_rents djisr_income_services djisr_income_wages djisr_income_other)
					
			rename (deduc_acti_mercantiles deduc_honorarios_prof deduc_por_inter_no_banc deduc_por_act_art20 deduc_por_alquileres ///
					 deduc_por_servicios deduc_sueldos_sal_boni deduc_otros_ingre_grav ) ///
					(djisr_deduction_commercial djisr_deduction_honorario djisr_deduction_interest ///
					djisr_deduction_art20 djisr_deduction_rents djisr_deduction_services djisr_deduction_wages djisr_deduction_other)
				
			gen ihss_basewage = .
		}
		
		if `year' == 2014 {
			destring djisr_deduction_art20, force replace
		}
		
		lab var dmr_111 "111 RETENCIÓN EN LA FUENTE ASALARIADOS"
		lab var dmr_112 "112 RETENCIÓN POR SERVICIOS, HONORARIOS  (ART. 50)"
		lab var dmr_113 "113 RETENCIÓN POR DIVIDENDOS O UTILIDADES DISTRIBUIDAS (ART. 25)"
		lab var dmr_115 "115 RETENCIÓN POR INTERESES Y RENDIMIENTOS FINANACIEROS (ART. 9)"
		lab var tpi_atc "Ventas por Tarjetas de crédito o débito"
		lab var tpi_siafi "Pagos que le efectuó el Gobierno al OT en el Sistema SIAFI"
		lab var tpi_dmc "Compras reportadas por Medianos y Grandes Contribuyentes que le hicieron al OT"
		lab var tpi_dmr_135 "RETENCIÓN ANTICIPO ISR 1%"
		lab var tpi_exports "Exportaciones que realizo el OT"
		lab var dmr_capitalgains "Income from Capital Gains"
		lab var dmr_rentalincome "Income from non-commercial rentals"
		lab var undistributed_corp_income "Income from Undistributed Corporate Income"
		lab var undistributed_corp_taxes "Undistributed Corporate Income Tax"
		
		order id year djisr_chr* djisr_income_* djisr* dmr_* tpi_* 
		
		
		merge 1:1 id using  "$databases/Output/CleanTaxData/Gender_age_dataset.dta", nogen keep(1 3)
		
		compress
	

		save "$databases/Output/CleanTaxData/TaxData_`year'.dta", replace
	}
}	


