*===============================================================================
* File name: 		2d_Inequality_CreateVars_loop.do
* 
* Description:		This do-file creates the TaxData_Analysis_`year'.dta datasets,
*					which have information on income and tax liability.
*
* Input:  					
*					$databases/Output/CleanTaxData/TaxData_`year'.dta
*
* Output:
*					$databases/Output/AnalysisTaxData/TaxData_Analysis_`year'.dta
*===============================================================================

quietly { 

foreach year of numlist 2003/2020 {
	
	use "$databases/Output/CleanTaxData/TaxData_`year'.dta", clear

	di in red "Creating variables for taxdata in `year'"
	
	include "$do/IncomeTaxBrackets"
		
	replace djisr_dummy_filed = 0 if djisr_dummy_filed == .

	
	/*===============================================================================================
									  1: Income Components
	===============================================================================================*/

	******************* 1.1: DISTRIBUTED CAPITAL INCOME IS WITHHELD, COMMON TO ALL TAXPAYERS **************************************

	egen aux_reported_dividends = rowtotal(dmr_113)
	egen aux_reported_interests = rowtotal(dmr_115)
	egen aux_reported_capgains  = rowtotal(dmr_capitalgains)
	egen aux_reported_rental    = rowtotal(dmr_rentalincome)

	egen final_capital_income_dist = rowtotal(aux_reported_dividends aux_reported_interests aux_reported_rental)    //Capital = final_capital_income_dist
	
	***************************** 1.1b: UNDISTRIBUTED PROFITS **********************************************************

	egen final_corp_income = rowtotal(undistributed_corp_income)    //Capital = Dividends + Interest
	
	
	***************************** 1.1b: UNDISTRIBUTED PROFITS **********************************************************
	
	egen final_capital_income_total = rowtotal(final_capital_income_dist final_corp_income)    //Capital total = Distributed capital income + undistributed profits
	
	******************* 1.2: CREATE INCOME FOR TAXPAYERS WITH NO INCOME TAX FILING **************************************
			
	gegen aux_reported_wage = rowtotal(dmr_111)

	egen aux_reported_sales = rowtotal(tpi_atc tpi_exports tpi_dmr_135)					//Total TPI on sales
	gen aux_reported_services_sales = max(dmr_112, aux_reported_sales)					//Max of Honorarios and Sales

	*Sales/Services are GROSS at this point; below will use median deductions from filing taxpayers to net out costs.
	
	******************* 1.3: CREATE INCOME FOR TAXPAYERS WITH INCOME TAX FILING **************************************

	*Grouping components of gross income declared in DJISR
	 egen aux_declared_wage 			= rowtotal(djisr_income_wages)
	 egen aux_declared_services 		= rowtotal(djisr_income_honorario djisr_income_services)
	 egen aux_declared_commercial 		= rowtotal(djisr_income_commercial djisr_income_art20)
	 egen aux_declared_interest_nobanc	= rowtotal(djisr_income_interest )
	 egen aux_declared_rent 			= rowtotal(djisr_income_rents)
	 egen aux_declared_other 			= rowtotal(djisr_income_other)
	 
	gegen aux_declared_gross_revenue = 	rowtotal(aux_declared_wage aux_declared_services ///
										aux_declared_commercial aux_declared_interest_nobanc aux_declared_rent aux_declared_other)
									
									
	/*There's clearly mislabeling between wage and honorarios/services in declarations, taxpayers mix the two.
	So we apply the rule: we want to make sure that the s um of wages, honorarios and service income is at least as large as
	TPI reported on these categories (DMR11 + DMR112) */
														
	gegen aux_declared_labor_services 	= rowtotal(aux_declared_wage  aux_declared_services)
	gegen aux_tpi_labor_services 		= rowtotal(aux_reported_wage dmr_112)
	gen aux_dmr_greater_wage_hon 		= aux_tpi_labor_services >= aux_declared_labor_services

	gen final_wage_unadj = .
	replace final_wage_unadj = aux_reported_wage 		if (aux_dmr_greater_wage_hon == 1)
	replace final_wage_unadj = aux_declared_wage    	if (aux_dmr_greater_wage_hon == 0)
	
	gen aux_service_adjusted = .
	replace aux_service_adjusted = dmr_112 	   if (aux_dmr_greater_wage_hon == 1)
	replace aux_service_adjusted = aux_declared_services   if ( aux_dmr_greater_wage_hon == 0)
	

	******* ADJUSTMENTS TO FINAL WAGE: INCLUDING 13/14TH WAGES + SOCIAL SECURITY CONTRIBUTIONS
	
	/* Adjusting wages for 13o and 14o salarios: we will assume all formal taxpayers receive those. 
	According to tax law (Ley de ISR art. 10 Literal h), both are exempt up to equivalent to 10 MW yearly, and are
	taxed as usual rates after that. Exempt income should not be reported, so we adjust to recover true income */
	
	loc minwage_exemption = 20*`minwage'
	
	gen extra_wages = min(final_wage_unadj*(2/12),`minwage_exemption') if (final_wage_unadj > 0 & final_wage_unadj != .)
	
	
	
	*****STEPS TO COMPUTE WORKER SS CONTRIBUTION. EMPLOYER IS NOT REPORTED, SO HAS TO BE ADDED
	
	**1. GROSS WAGE SHOULD INCLUDE  WORKERS CONTRIBUTION, SINCE IT CAN BE INCLUDED AS DEDUCTION. 
	** SO GROSS WAGE = (1+`worker_rate')*NET WAGE ==> NET WAGE = GROSS WAGE / (1+`worker_rate')
	
	gen reference_wage_noextra = .
	replace reference_wage_noextra = final_wage_unadj if extra_wages < `minwage_exemption'
	replace reference_wage_noextra = (final_wage_unadj-`minwage_exemption')/(1+2/12) if extra_wages == `minwage_exemption'		//if 13/14 are too high, they are taxable and thus reported. Subtract them
	
	*Wage net of SSC depends on whether it's larger or smaller than ceiling
	gen w1 = reference_wage_noextra - `worker_rate'*`ceiling_contr'
	gen w2 = reference_wage_noextra/(1+`worker_rate')
	
	gen wage_netSSC = max(w1,w2)
	
	gen worker_contr_ss = `worker_rate'*min(`ceiling_contr',wage_netSSC) if wage_netSSC != .			//Worker contribution
	replace worker_contr_ss = 0 if worker_contr_ss == .
	
	gen employer_contr_ss = `employer_rate'*min(`ceiling_contr',wage_netSSC) if wage_netSSC != .		//Employer contributions
	replace employer_contr_ss = 0 if employer_contr_ss == .
	
	egen final_gross_wage = rowtotal(wage_netSSC extra_wages worker_contr_ss  employer_contr_ss)		//Note: Gross wage is total labor cost, including both employee and employer contributions
	
	/*********I will now consider deductions by category*********/
	 gegen aux_deduct_wage = rowtotal(djisr_deduction_wages)
	 gegen aux_deduct_services = rowtotal(djisr_deduction_honorario djisr_deduction_services)
	 gegen aux_deduct_commercial = rowtotal(djisr_deduction_commercial djisr_deduction_art20)
	 gegen aux_deduct_interest_nobanc = rowtotal(djisr_deduction_interest)
	 gegen aux_deduct_rent = rowtotal(djisr_deduction_rents)
	 gegen aux_deduct_other = rowtotal(djisr_deduction_other)
	 
	gegen aux_declared_deductions = rowtotal(aux_deduct_wage aux_deduct_services aux_deduct_commercial ///
												aux_deduct_interest_nobanc aux_deduct_rent aux_deduct_other)

	*Net out deductions from Services, Commercial, Interest, Rent and Others. Note that for services we use adjusted gross income from above
	gen final_net_wage = final_gross_wage - worker_contr_ss - max(aux_deduct_wage - worker_contr_ss,0)			//we deduct at least the workers SSC; and more if they claim more
	gen final_net_service = aux_service_adjusted - aux_deduct_services
	gen final_net_commercial = aux_declared_commercial - aux_deduct_commercial
	gen final_net_interest_nobanc = aux_declared_interest_nobanc - aux_deduct_interest_nobanc
	gen final_net_rent = aux_declared_rent - aux_deduct_rent
	gen final_net_other = aux_declared_other - aux_deduct_other

	gegen adjusted_gross_activities_rev = rowtotal(final_gross_wage aux_service_adjusted  aux_declared_commercial  aux_declared_interest_nobanc ///
											aux_declared_rent  aux_declared_other)
	
	if inrange(`year', 2003, 2010 ) {
	
		*Those years had few deductions, so we use final net income to adjust gross income by component
		gen deduct_impute = djisr_gross_income - (utilidaddelejercicio - perdidadelejercicio)
		egen aux_grossrev = rowtotal(djisr_income_commercial djisr_income_services djisr_income_art20 ///
				djisr_income_wages djisr_income_honorario djisr_income_rents djisr_income_interest djisr_income_other)
		
		replace final_net_wage = final_gross_wage - (djisr_income_wages/aux_grossrev)*deduct_impute
		replace final_net_service = aux_service_adjusted - (aux_declared_services/aux_grossrev)*deduct_impute
		replace final_net_commercial = aux_declared_commercial - (aux_declared_commercial/aux_grossrev)*deduct_impute
		replace final_net_interest_nobanc = aux_declared_interest_nobanc - (aux_declared_interest_nobanc/aux_grossrev)*deduct_impute
		replace final_net_rent = aux_declared_rent - (aux_declared_rent/aux_grossrev)*deduct_impute
		replace final_net_other = aux_declared_other - (aux_declared_other/aux_grossrev)*deduct_impute
		drop deduct_impute aux_grossrev
	}
	
	/**Now we computed everything from tax filing. But for some individuals, total third-party information (TPI) on GROSS income
	is still larger than total gross income reported, including all adjustmends for TPI. So we compute that difference, apply
	median profit margin by department-by-economic sector, and obtain additional net income attributed to them */
	gen dummy_underreport = tpi_total > adjusted_gross_activities_rev & tpi_total != .
	gen diff_tpi = (tpi_total - adjusted_gross_activities_rev) if dummy_underreport == 1


	**Computing profit margins from commercial activities
	gen profit_margin_commercial = max(0,final_net_commercial)/aux_declared_commercial		
	sort djisr_chr_departamento act_div_code
	gegen median_margin = median(profit_margin_commercial), by(djisr_chr_municipio act_div_code)
	gegen median_margin_act = median(profit_margin_commercial), by(act_section)
	replace profit_margin_commercial = median_margin if profit_margin_commercial == .
	replace profit_margin_commercial = median_margin_act if profit_margin_commercial == .

	gen final_unreported_netincome = diff_tpi*profit_margin_commercial



	*************** 1.4: CREATE SUBCOMPONENTS AND FINAL INCOME FOR BOTH TYPES OF TAXPAYERS  **************************************

	***For non-filing taxpayers, apply median profit margin to gross revenues***
	gen final_net_reported_sales = profit_margin_commercial*aux_reported_services_sales					//Sales are gross income, apply median profit margin to get net
	gen aux_net_sales_dummy = final_net_reported_sales > 0

	gen final_wage = final_net_wage

	egen final_mixed = rowtotal(final_net_service final_net_commercial final_net_interest_nobanc final_net_rent ///
								final_net_other final_unreported_netincome) if djisr_dummy_filed == 1
	replace final_mixed = final_net_reported_sales  if djisr_dummy_filed == 0
	replace final_mixed = 0 if final_mixed == .
	
	egen total_final = rowtotal(final_capital_income_dist final_wage final_mixed)
	replace total_final = 0 if total_final < 0
	
	**ADDING UNDISTRIBUTED PROFITS
	egen total_final_und = rowtotal(final_capital_income_dist final_wage final_mixed final_corp_income)
	replace total_final_und = 0 if total_final_und < 0
	
	*************** 1.5: CREATE INDICATORS FOR TOP WAGES  **************************************
	
	gsort -total_final
	gen rank_nocorp = _n
	
	gsort -total_final_und
	gen rank = _n

	***** Alternative income measure for filing taxpayers: declared net income, unadjusted for third-parties, BUT including
	* capital income (since it doesn;t need to be reported as taxable income)
	gen net_income_filed = max(0,djisr_gross_income - djisr_deductions)	
	gegen alternative_total_filed_only =  rowtotal(net_income_filed final_capital_income_dist)
		
	gen log_income_all = ln(total_final)


	*************** 1.6: APPLY STATUTORY TAX RATES  **************************************
	
	*10% on capital income (including capital gains and non-commercial rental)
	gen taxes_capital = 0.1*final_capital_income_dist
	gen taxes_div_pluscorp = .25*aux_reported_dividends
	gen withheld_112 = 0.125*dmr_112
	
	gen dmr_111_net = max(dmr_111 - 40000,0)				//Important: DMR 111 is gross of 40k, we net it out
	gen withheld_111 = .
	replace withheld_111  = 0  if dmr_111_net < `first_bracket'
	replace withheld_111  = 0.15*(dmr_111_net - `first_bracket')  if inrange(dmr_111_net, `first_bracket',`second_bracket')
	replace withheld_111  = 0.15*(`second_bracket' - `first_bracket') + 0.2*(dmr_111_net - `second_bracket') ///
																if inrange(dmr_111_net, `second_bracket',`third_bracket')
	replace withheld_111  = 0.15*(`second_bracket' - `first_bracket') + 0.2*(`third_bracket' - `second_bracket') ///
									+ 0.25*(dmr_111_net - `third_bracket') if inrange(dmr_111_net, `third_bracket',.)
	

									
	egen withheld_total = rowtotal(withheld_111 withheld_112)
	*On remaining income, progressive schedule with marginal tax rates of 15, 20 and 25%
	
	/* E.g. for 2018
	Lower bound // Upper bound // marginal rate
		0.01		152,557.15			0%
	 152,557.16		232,622.61			15%
	 232,622.62		540,982.82			20%
	 540,982.83	 	adelante 			25%*/

	gegen exempt_addsalary = rowtotal(extra_wages)

	egen taxable_income = rowtotal(final_wage final_mixed)
	replace taxable_income = taxable_income - 40000	- exempt_addsalary				//Medical deductions of 40k (apply for all OTs)							
	
	gen taxes_isr = .
	replace taxes_isr  = 0  if taxable_income < `first_bracket' 
	replace taxes_isr  = 0.15*(taxable_income - `first_bracket')  if inrange(taxable_income, `first_bracket',`second_bracket')
	replace taxes_isr  = 0.15*(`second_bracket' - `first_bracket') + 0.2*(taxable_income - `second_bracket') ///
																if inrange(taxable_income, `second_bracket',`third_bracket')
	replace taxes_isr  = 0.15*(`second_bracket' - `first_bracket') + 0.2*(`third_bracket' - `second_bracket') ///
									+ 0.25*(taxable_income - `third_bracket') if inrange(taxable_income, `third_bracket',.)

	if inrange(`year', 2003, 2010) {
		gen impuesto_segun_tarifa = .
	}
	
	***Actual taxes on labor incomes if filed (from tax form) or not filed (withholding)
	gen taxes_actual = .
	replace taxes_actual = impuesto_segun_tarifa if djisr_dummy_filed == 1
	replace taxes_actual = withheld_total 		 if djisr_dummy_filed == 0
	
	*Taxes on corporations: we use flat 25% tax rate, regardless of exemptions or minimum
	egen tax_corp = rowtotal(undistributed_corp_taxes)
	gen tax_corp_naive = max(0,.25*final_corp_income)
	
	gen posttax_total 					= total_final - taxes_capital - taxes_isr
	gen posttax_total_actual 			= total_final - taxes_capital - taxes_actual
	gen posttax_total_actual_extradiv 	= total_final - taxes_capital - taxes_actual - taxes_div_pluscorp
	gen posttax_total_withcorp 			= total_final_und - taxes_capital - taxes_actual - tax_corp
	
	order id total_final total_final_und rank final_capital_income_total final_wage final_mixed final_capital_income_dist final_corp_income total_final_und posttax*  

	lab var total_final_und "Total Yearly income w/ corporate income"
	lab var total_final "Total Yearly income"
	lab var rank "Rank in income distribution"
	lab var final_capital_income_total "Capital Income (dist + undist)" 
	lab var final_capital_income_dist "Distributed Capital Income" 
	lab var final_wage "Wage Income"
	lab var final_mixed "Mixed Income"
	lab var final_corp_income "Undistributed corporate profits"

	save "$databases/Output/AnalysisTaxData/TaxData_Analysis_`year'.dta", replace						
}

}
