/* --------------------------------------------------------------------------- */
* File name: 		3b_DescriptivesPJ.do
* 
* Description:		This do file generates paper Figures 4 (a) and 4 (b)
*
* Input:  					
*					$data/ISRPJ2021_withShareholderInfo.dta
*
* Output:			$figures/`date'_share_socios_comp_top.png
*					$figures/`date'_share_rev_prof_combined.png
*					
/* --------------------------------------------------------------------------- */

/* Set up */
capture log close
graph set ps logo off
set more off 
clear all
set max_memory 240g
set maxvar 120000

set graphics on  
set varabbrev off, permanent
set scheme s1color

local date: di %tdYYNNDD date(c(current_date), "DMY")
di "`date'"

/* -------------------- */
/* GRAPHS FOR ALL FIRMS */
/* -------------------- */
	
use "$databases/Output/ShareholdersData/ISRPJ2021_withShareholderInfo.dta", clear

	replace adjusted_share_valid=0 if adjusted_share_valid==.

	gen turnover_valid 		= adjusted_share_valid*turnover2021
	gen profit_valid   		= adjusted_share_valid*profit2021
	
	gsort -turnover2021
	gen rank = _n
	egen top_groups = cut(rank), at(0 100 500 1000 5000 10000 30000 40000)
	
	global vars turnover2021 turnover_valid  profit_valid profit2021
	
	foreach var of varlist $vars {
		replace `var'=`var'/1000
	}
	
order id_informante top_groups profit2021 profit_valid turnover2021 turnover_valid

/* All firms */
preserve
	gcollapse (mean) shareholder_pj foreign_shareholder (sum) turnover2021 turnover_valid, by(top_groups)
	
	gsort -top_groups
	gen n = _n
	
	gen share_turn_valid   = turnover_valid/turnover2021

	/* Save tempfile */
	tempfile temp_all
	save `temp_all', replace

	/* Figure 6a */
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway  (scatter foreign_shareholder 	n, mc(purple%75) c(l) lc(purple%50) lw(medthick)) ///
			(scatter shareholder_pj 		n, mc(red%75) c(l) lc(red%50) lw(medthick)), ///
			xlabel(1 "Top 40,000" 2 "Top 30,000" 3 "Top 10,000" 4 "Top 5,000" 5 "Top 1,000" ///
			6 "Top 500" 7"Top 100", angle(90) labsize(medium)) ///
			ylab(0(.2)1, format(%12.1fc) labsize(medium) glp(dash) glw(vthin)) ///
			ytitle("Share of Shareholders", size(medlarge)) xtitle("Top Firms 2021 (Revenue)", size(medlarge)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xscale(titlegap(3)) yscale(titlegap(3)) ///
			text(.5 5.5 "Foreign Shareholder", size(small) color(purple)) ///
			text(.18 6 "Firm Shareholder", size(small) color(red))
	graph export "$figures/Figure_4_A.png", replace width(1200) height(1000)
			
restore

/* --------------------------------------------------------------------------------------------- */
/* GRAPHS FOR FIRMS WITH NON-NEGATIVE PROFITS, KEEPING THE RANKING CREATED USING THE FULL SAMPLE */
/* --------------------------------------------------------------------------------------------- */

/* Graph versions excluding cases with negative profits */
preserve
	
	/* Drop observations with negative profits */
	drop if profit2021<0
	
	gcollapse (sum) profit2021 profit_valid, by(top_groups)
	
	gsort -top_groups
	gen n = _n
	
	gen share_profit_valid = profit_valid/profit2021
	
	/* Save tempfile */
	tempfile temp_noneg
	save `temp_noneg', replace

restore

/* ------------------------------------------------ */
/* GRAPHS FOR FIRMS WITH ALL & NON-NEGATIVE PROFITS */
/* ------------------------------------------------ */

use `temp_noneg', clear

ren * *_noneg
ren top_groups_noneg top_groups

merge 1:1 top_groups using  `temp_all'
drop _merge

	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter share_turn_valid n , mc(blue%75) c(l) lc(blue%50) lw(medthick)) ///
			(scatter share_profit_valid_noneg n, mc(green%75) c(l) lc(green%50) lw(medthick)), ///
			xlabel(1 "Top 40,000" 2 "Top 30,000" 3 "Top 10,000" 4 "Top 5,000" 5 "Top 1,000" ///
			6 "Top 500" 7"Top 100", angle(90) labsize(medium))  yscale(titlegap(3)) ///
			ylab(0(.2)1, format(%12.1fc) labsize(medium) glp(dash) glw(vthin)) ///
			ytitle("Share Assigned to a Valid RTN", size(medlarge)) xtitle("Top Firms 2021 (Revenue)", size(medlarge)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xscale(titlegap(3)) yscale(titlegap(3)) ///
			text(.9 2.5 "Turnover", size(medsmall) color(blue%75)) ///
			text(.7 2.5 "Profits", size(medsmall) color(green%75))
	graph export "$figures/Figure_4_B.png", replace width(1200) height(1000) 