/* --------------------------------------------------------------------------- */
* File name: 		Effective_Tax_Rates_Other.do
* 
* Description:		This do-file generates some extra analysis requested 
*					by the PIs
*
* Input:  					
*					$databases/Output/AnalysisTaxData/TaxData_Analysis_`year'.dta
*					$databases/Inputs/AuxData/inflation.dta
*					$databases/Output/Auxiliary/survey_population.dta
*					$databases/Inputs/AuxData/WID_PPP.dta
*
* Output:
*					$tables/`date'_French_Table_`year'.tex
/* --------------------------------------------------------------------------- */

/* Set up */
capture log close
graph set ps logo off
set more off 
clear all
set max_memory 240g
set maxvar 120000

set graphics on  
set varabbrev off, permanent
set scheme s1color

local date: di %tdYYNNDD date(c(current_date), "DMY")
di "`date'"

/* ------------ */
/* Load dataset */
/* ------------ */

foreach year in 2019 {

use "$databases/Output/AnalysisTaxData/TaxData_Analysis_`year'.dta", clear

drop if (total_final < 1000 & total_final_und < 1000)

/* --------------------- */
/* Merge additional data */
/* --------------------- */

merge m:1 year using "$databases/Inputs/AuxData/inflation.dta"
drop if _merge == 2
drop _merge
		
merge m:1 year using "$databases/Inputs/AuxData/WID_PPP.dta"
drop if _merge == 2
drop _merge

/* Set population levels */
gen population=5422097 if year==2019

/*
Population levels come from survey data publicly available at the Instituto Nacional de Estadística (https://ine.gob.hn/v4/ephpm/)
*/

/* ------------------------------------------------------------------------------------- */
/* Rank taxpayers based on their income, both the with and without undistributed profits */
/* ------------------------------------------------------------------------------------- */

cap drop rank
gen factor = 1

gsort year -total_final_und
by year: gen position_und = sum(factor)
gen share_position_und = position_und/population

gen total_final_2010 = (total_final*100/inflationindex)	
gen total_final_usd = total_final/ppp_exchange

gen first_bracket=.
replace first_bracket=110000+40000 if year==2013
replace first_bracket=141000+40000 if year==2016
replace first_bracket=152557.16+40000 if year==2018 
replace first_bracket=158995.06+40000 if year==2019
replace first_bracket=172117+40000 if year==2021
replace first_bracket=181274+40000 if year==2022

/* Threshold based on total income */
gen above_threshold_total = (total_final_und > first_bracket)

/* Fix variables */
foreach var of varlist  large_shareholder profit_losses large_share_firm total_profit_losses {
	replace `var' = 0 if `var' == .
}

/* Keep those only above the exemption threshold */
keep if above_threshold_total==1
egen groups_position_merged_und = cut(share_position_und), at(0 0.00001 0.00002 0.00003 0.00004 0.00005 0.00006 0.00007 0.00008 0.00009 ///
																0.0001 0.0002 0.0003 0.0004 0.0005 0.0006 0.0007 0.0008 0.0009  ///
																0.001 0.002 0.003 0.004 0.005 0.006 0.007 0.008 0.009 ///
																0.01 0.011 0.012 0.013 0.014 0.015)

/* Organize data */
order id year total_final_und position_und above_threshold_total population share_position_und groups_position_merged_und

gen share_position_und_perc=share_position_und*100
order share_position_und_perc, a(share_position_und)

/* Keep only ranked individuals */
keep if year == `year'
drop if groups_position_merged_und == .

/* Keep main variables */
keep id year position_und total_final_und total_final groups_position_merged_und share_position_und share_position_und_perc

replace total_final_und=total_final_und/1000
replace total_final=total_final/1000

/* Get percentile income threshold */
sort groups_position_merged_und position_und
by groups_position_merged_und: egen income_limit=min(total_final_und)

/* Fix groups_position_merged_und value */
replace groups_position_merged_und=groups_position_merged_und*100

replace groups_position_merged_und=groups_position_merged_und+0.001 if income_limit>9000 						
replace groups_position_merged_und=groups_position_merged_und+0.01  if income_limit<7000 & income_limit>1000 	
replace groups_position_merged_und=groups_position_merged_und+0.1  if income_limit<1000 				

/* Generate percentile */
gen percentile=100-groups_position_merged_und

/* Mean income for those beyond each limit */
gen groups_vars=groups_position_merged_und*1000
replace groups_vars=round(groups_vars)

levelsof groups_vars, local(groups)

gen mean_income_beyond_total=.

local n=0
foreach i in `groups' {
local n=`n'+1		
	egen mean_`n'=mean(total_final_und) if groups_vars<=`i'
	replace mean_income_beyond_total=mean_`n' if groups_vars==`i'
}

ren mean_income_beyond_total income_beyond_mean_total
drop mean_*

/* Mean income WITHOUT UND. PROFITS for those beyond each limit */
levelsof groups_vars, local(groups)

gen mean_income_beyond=.

local n=0
foreach i in `groups' {
local n=`n'+1		
	egen mean_`n'=mean(total_final) if groups_vars<=`i'
	replace mean_income_beyond=mean_`n' if groups_vars==`i'
}

ren mean_income_beyond income_beyond_mean
drop mean_*

/* Number of individuals beyond each limit */
gen n=1

levelsof groups_vars, local(groups)

gen total_n=.

local n=0
foreach i in `groups' {
local n=`n'+1		
	egen total_n_`n'=total(n)   if groups_vars<=`i'
	replace total_n=total_n_`n' if groups_vars==`i'
}

drop total_n_*

/* Collapse data at the percentile level */
gcollapse (mean) percentile total_n income_limit income_beyond_mean_total income_beyond_mean, by(year groups_position_merged_und groups_vars)
gsort year -groups_position_merged_und

/* Keep selected percentiles */
keep if groups_vars==1500 | groups_vars==1000 | groups_vars==100 | groups_vars==10 | groups_vars==5 | groups_vars==4 | groups_vars==3 | groups_vars==2 | groups_vars==1

/* Get numbers for table */
levelsof groups_vars, local(groups)

local n=0
foreach i in `groups' {
local n=`n'+1		
	qui summ percentile 					if `i'==groups_vars
	local p_`i'	=round(`r(mean)', 0.001)

	qui summ total_n 						if `i'==groups_vars
	local n_`i'=round(`r(mean)')
	local n_`i': di %15.0fc `n_`i''
	
	qui summ income_limit 					if `i'==groups_vars
	local l_`i'=round(`r(mean)')
	local l_`i': di %15.0fc `l_`i''
	
	local l_`i'_usd=round(`r(mean)'/11.3)
	local l_`i'_usd: di %15.0fc `l_`i'_usd'	
	
	qui summ income_beyond_mean_total 		if `i'==groups_vars
	local inctot_`i'=round(`r(mean)')
	local inctot_`i': di %15.0fc `inctot_`i''

	local inctot_`i'_usd=round(`r(mean)'/11.3)
	local inctot_`i'_usd: di %15.0fc `inctot_`i'_usd'
	
	qui summ income_beyond_mean		 		if `i'==groups_vars
	local inc_`i'=round(`r(mean)')
	local inc_`i': di %15.0fc `inc_`i''
	
	local inc_`i'_usd=round(`r(mean)'/11.3)
	local inc_`i'_usd: di %15.0fc `inc_`i'_usd'
	
}

foreach i in `groups' {	
	di `i'
	di `p_`i''
	di `n_`i''
	di `l_`i''
	di `inctot_`i''
	di `inc_`i''
}

/* Make table */
capture file close myfile
file open myfile using "$tables/Table_1.tex", write replace
file write myfile ///
" \\ \\ [-1.5ex] " _n ///
" \hline\hline \\ [-1.5ex] " _n ///
" {} & (1) & (2) & (3) & (4)  \\ " _n ///
" [1ex] \\ [-1.5ex] " _n ///
"                	& Number of         & Annual       			& Mean Annual     			& Mean Annual  			\\	" _n ///
" Percentile      	& Individuals       & Comprehensive 		& Comprehensive     		& Income    			\\	" _n ///
"                	& Above   			& Income   				& Income      				& Beyond Threshold 		\\	" _n ///
"                	& that Level  		& Threshold   			& Beyond Threhold   		& Exc. Und. Profits 	\\	" _n ///
"                	\\ [-1ex]																					  	  	" _n ///
"                 	&            		& \small{000s HNL}  	& \small{000s HNL}			& \small{000s HNL}  	\\	" _n ///
"					&                	& \small{[000s USD PPP]}& \small{[000s USD PPP]}    & \small{[000s USD PPP]}\\	" _n ///
" [1ex] \hline \\ [-1.5ex]																					   			" _n ///
" `p_1500' 			& `n_1500'			& `l_1500'				& `inctot_1500'			& `inc_1500'		 		\\	" _n ///
" 		 			& 					& [`l_1500_usd']		& [`inctot_1500_usd']	& [`inc_1500_usd']		 	\\	" _n ///
" `p_1000' 			& `n_1000'			& `l_1000'				& `inctot_1000'			& `inc_1000'		 		\\	" _n ///
" 		 			& 					& [`l_1000_usd']		& [`inctot_1000_usd']	& [`inc_1000_usd']		 	\\	" _n ///
" `p_100' 			& `n_100'			& `l_100'				& `inctot_100'			& `inc_100'			 		\\	" _n ///
" 		 			& 					& [`l_100_usd']			& [`inctot_100_usd']	& [`inc_100_usd']		 	\\	" _n ///
" `p_10' 			& `n_10'			& `l_10'				& `inctot_10'			& `inc_10'			 		\\	" _n ///
" 		 			& 					& [`l_10_usd']			& [`inctot_10_usd']		& [`inc_10_usd']		 	\\	" _n ///
" `p_5' 			& `n_5'				& `l_5'					& `inctot_5'			& `inc_5'			 		\\	" _n ///
" 		 			&					& [`l_5_usd']			& [`inctot_5_usd']		& [`inc_5_usd']			 	\\	" _n ///
" `p_4' 			& `n_4'				& `l_4'					& `inctot_4'			& `inc_4'			 		\\	" _n ///
" 		 			& 					& [`l_4_usd']			& [`inctot_4_usd']		& [`inc_4_usd']			 	\\	" _n ///
" `p_3' 			& `n_3'				& `l_3'					& `inctot_3'			& `inc_3'			 		\\	" _n ///
" 		 			& 					& [`l_3_usd']			& [`inctot_3_usd']		& [`inc_3_usd']			 	\\	" _n ///
" `p_2' 			& `n_2'				& `l_2'					& `inctot_2'			& `inc_2'			 		\\	" _n ///
" 		 			& 					& [`l_2_usd']			& [`inctot_2_usd']		& [`inc_2_usd']			 	\\	" _n ///
" `p_1' 			& `n_1'				& `l_1'					& `inctot_1'			& `inc_1'			 		\\	" _n ///
" 		 			&					& [`l_1_usd']			& [`inctot_1_usd']		& [`inc_1_usd']			 	\\	" _n ///
" [1ex] \hline\hline \\ [-1.5ex] 																			   			"
capture file close myfile

}