/* --------------------------------------------------------------------------- */
* File name: 		Effective_Tax_Rates_top15_intervals.do
* 
* Description:		This do-file generates paper figures F1, F2, F3, F5, and FA1
*
* Input:  					
*					$databases/output/TaxData_Analysis_`year'.dta
*					$databases/Inputs/AuxData/inflation.dta
*					$databases/Output/Auxiliary/survey_population.dta
*					$databases/Inputs/AuxData/WID_PPP.dta
*
* Output:			
*					$figures/`date'_ETRs_Top15_Corp_19_Int.png
*					$figures/`date'_ETRs_DispersionMedian_2019_Top15_Int.png
*					$figures/`date'_ETRs_ByYear_Top15_Int.png.png
*					$figures/`date'_ETRs_Composition_Top15_`year'_Int.png
*					$figures/`date'_Share_Income_Composition_Line_Top15_Int.png
*					$figures/`date'_Income_Total_Top15_LogScale_Int_2.png
*					$figures/`date'_Share_Shareholders_All_Major.png
*					$figures/`date'_Number_Firms_Shareholders.png
*					$figures/`date'_Share_Individuals_Profits_Exempt.png
*
/* --------------------------------------------------------------------------- */

/* Set up */
capture log close
// graph set ps logo off
// set more off 
 clear all
// set max_memory 240g
// set maxvar 120000
//
// set graphics on  
// set varabbrev off, permanent
// set scheme s1color
// graph set window fontface "LM Roman 10"
// graph set print fontface "LM Roman 10"

local date: di %tdYYNNDD date(c(current_date), "DMY")
di "`date'"

/* ------------------------------------------------------------------------- */
/* New set of graphs keeping all the taxpayers above the exemption threshold */
/* ------------------------------------------------------------------------- */

/* ------------ */
/* Load dataset */
/* ------------ */
clear all
foreach year in 2013 2016 2018 2019 {
	qui append using "$databases/Output/AnalysisTaxData/TaxData_Analysis_`year'.dta"
	drop if (total_final < 1000 & total_final_und < 1000)								// drop very low incomes, since we focus on top here
}

drop if (total_final < 1000 & total_final_und < 1000)

/* --------------------- */
/* Merge additional data */
/* --------------------- */

merge m:1 year using "$databases/Inputs/AuxData/inflation.dta"
drop if _merge == 2
drop _merge

merge m:1 year using "$databases/Inputs/AuxData/WID_PPP.dta"
drop if _merge == 2
drop _merge

/* Set population levels */
gen 	population=4629741 if year==2013
replace population=4854346 if year==2016
replace population=5252097 if year==2018
replace population=5422097 if year==2019

/*
Population levels come from survey data publicly available at the Instituto Nacional de Estadística (https://ine.gob.hn/v4/ephpm/)
*/

/* ------------------------------------------------------------------------------------- */
/* Rank taxpayers based on their income, both the with and without undistributed profits */
/* ------------------------------------------------------------------------------------- */

cap drop rank
gen factor = 1

gsort year -total_final_und
by year: gen position_und = sum(factor)
gen share_position_und = position_und/population

gen total_final_2010 = (total_final*100/inflationindex)	
gen total_final_usd = total_final/ppp_exchange

gen first_bracket=110000+40000 if year==2013
replace first_bracket=141000+40000 if year==2016
replace first_bracket=152557.16+40000 if year==2018 
replace first_bracket=158995.06+40000 if year==2019

/* Threshold based on total income */
gen above_threshold_total = (total_final_und > first_bracket)

/* Fix variables */
foreach var of varlist  large_shareholder profit_losses large_share_firm total_profit_losses number_corps_largeshare number_corps exempt_any share_profits_exempt {
	replace `var' = 0 if `var' == .
}

/* Keep those only above the exemption threshold */
keep if above_threshold_total==1
egen groups_position_merged_und = cut(share_position_und), at(0 0.00001 0.00002 0.00003 0.00004 0.00005 0.00006 0.00007 0.00008 0.00009 ///
																0.0001 0.0002 0.0003 0.0004 0.0005 0.0006 0.0007 0.0008 0.0009  ///
																0.001 0.002 0.003 0.004 0.005 0.006 0.007 0.008 0.009 0.01 0.011 ///
																0.012 0.013 0.014 0.015)

/* Organize data */
order id year total_final_und position_und above_threshold_total population share_position_und groups_position_merged_und

gen share_position_und_perc=share_position_und*100
order share_position_und_perc, a(share_position_und)

/* ----------------- */
/* ETR including CIT */
/* ----------------- */

preserve
	keep if year == 2019
	drop if groups_position_merged_und == .
	
	gen posttax_total_withcorp_extradiv=posttax_total_withcorp-taxes_div_pluscorp
	gen etr	= 100*(1-posttax_total_withcorp_extradiv/total_final_und)
	
	gen ind=1
	
	gcollapse (mean) etr (sum) ind, by(year groups_position_merged_und)  
	
	gsort year -groups_position_merged_und
	by year: gen n = _n
	
	insobs 1, before(15)
	insobs 1, before(25)
	
	replace year=year[_n-1] if year==.
	
	drop n
	gen n=_n
	
	local date: di %tdYYNNDD date(c(current_date), "DMY")	
	twoway 	(scatter etr n, mc(blue%60) cmissing(n) msize(small) c(l) lc(blue%40)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(small)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(0(5)30, format(%12.0fc) labsize(small)) ytitle("Effective Tax Rate (%)", size(medsmall)) 			
			graph export "$figures/Figure_2.png", replace width(1200) height(1000)

restore

/* ------------------- */
/* Dispersion analysis */
/* ------------------- */
preserve
	keep if year == 2019
	drop if groups_position_merged_und == .
		
	gen posttax_total_withcorp_extradiv=posttax_total_withcorp-taxes_div_pluscorp
	gen etr	= 100*(1-posttax_total_withcorp_extradiv/total_final_und)
		
	gcollapse (mean) etr_mean=etr (median) etr_median=etr (p25) etr_p25=etr (p75) etr_p75=etr, by(year groups_position_merged_und)  

	/* Sort data and create rank */
	gsort year -groups_position_merged_und
	by year: gen n = _n

	insobs 1, before(15)
	insobs 1, before(25)
	
	replace year=year[_n-1] if year==.
	
	drop n
	gen n=_n
	
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter etr_median 	n 	if year==2019, cmissing(n) mc(green%25) 		msize(small) 	c(l) lc(green%75)) ///
			(rcap etr_p25 etr_p75 	n 	if year==2019, cmissing(n) mc(green%25) 		msize(small) 	c(l) lc(green%30) lp(dash)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(, format(%12.0fc) labsize(medium)) ytitle("Effective Tax Rate (%)", size(medlarge)) 
			graph export "$figures/Figure_3_B.png", replace width(1200) height(1000)
restore

/* ------------ */
/* ETRs by year */
/* ------------ */
preserve
drop if groups_position_merged_und == .
	
gen posttax_total_withcorp_extradiv=posttax_total_withcorp-taxes_div_pluscorp
gen etr	= 100*(1-posttax_total_withcorp_extradiv/total_final_und)
	
gcollapse (mean) etr, by(year groups_position_merged_und)  

/* Sort data and create rank */
gsort year -groups_position_merged_und
by year: gen n = _n

	insobs 1, before(15)
	insobs 1, before(25)
	insobs 1, before(50)
	insobs 1, before(60)
	insobs 1, before(85)
	insobs 1, before(95)
	insobs 1, before(120)
	insobs 1, before(130)
	
	replace year=year[_n-1] if year==.
	
	replace n=. if n!=1
	replace n=n[_n-1]+1 if n[_n-1]!=. & n[_n+1]==.
	replace n=n[_n-1]+1 if n==.

/* Effective tax rates: graph ETRs */
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter etr n if year==2013, mc(purple%75)  	msize(small) c(l) cmissing(n) lc(purple%50)) ///
			(scatter etr n if year==2016, mc(midgreen%75) 	msize(small) c(l) cmissing(n) lc(midgreen%50)) ///
			(scatter etr n if year==2018, mc(cranberry%75) 	msize(small) c(l) cmissing(n) lc(cranberry%50)) /// 
			(scatter etr n if year==2019, mc(blue%75) 		msize(small) c(l) cmissing(n) lc(blue%50)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(small)) ///
			text(18 31 "2013", size(vsmall) color(purple)) ///
			text(30 30.5 "2016", size(vsmall) color(midgreen)) ///
			text(31.5 32 "2018", size(vsmall) color(cranberry)) ///
			text(30 27 "2019", size(vsmall) color(blue)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(, format(%12.0fc) labsize(small)) ytitle("Effective Tax Rate (%)", size(medsmall)) 		
			graph export "$figures/Figure_A1.png", replace width(1200) height(1000)		
restore

/* ------------------------------------------------- */
/* Effective Tax Rate Compositon, 2019 + other years */
/* ------------------------------------------------- */
preserve
	drop if groups_position_merged_und == .
	
	gen posttax_total_withcorp_extradiv=posttax_total_withcorp-taxes_div_pluscorp
	gen etr	= 100*(1-posttax_total_withcorp_extradiv/total_final_und)
	
	gen taxes_capital_extradiv	= taxes_capital+taxes_div_pluscorp

	gen etr_labor 	= 100*taxes_actual/total_final_und
	gen etr_capital	= 100*taxes_capital_extradiv/total_final_und
	gen etr_corp	= 100*tax_corp/total_final_und
	gen str_labor	= 100*taxes_isr/total_final_und
	
	gcollapse (mean) etr etr_labor etr_capital etr_corp str_labor taxable_income total_final_und, by(year groups_position_merged_und)
	
	gsort year -groups_position_merged_und
	by year: gen n = _n
	
	gen sum1=etr_labor+etr_capital
	gen sum2=sum1+etr_corp
	
	insobs 1, before(15)
	insobs 1, before(25)
	insobs 1, before(50)
	insobs 1, before(60)
	insobs 1, before(85)
	insobs 1, before(95)
	insobs 1, before(120)
	insobs 1, before(130)
	
	replace year=year[_n-1] if year==.
	
	replace n=. if n!=1
	replace n=n[_n-1]+1 if n[_n-1]!=. & n[_n+1]==.
	replace n=n[_n-1]+1 if n==.
	
/* Stacked area graph */
local date: di %tdYYNNDD date(c(current_date), "DMY")

foreach year in 2019 {
	
	twoway 	(area  etr_capital 			n if year==`year', lw(vthin) 	lc(cranberry%75) 	cmissing(n) col(cranberry%50)) ///
			(rarea etr_capital 	sum1	n if year==`year', lw(vthin)	lc(green%75) 		cmissing(n) col(green%50)) /// 
			(rarea sum1 		sum2	n if year==`year', lw(vthin)	lc(blue%75) 		cmissing(n) col(blue%50)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			text(19 	8 "Capital Income Tax", 	size(small) color(cranberry)) ///
			text(22 	8 "Labor Income Tax", 		size(small) color(green)) ///
			text(28 	8 "Undistributed Corporate", 	size(small) color(blue)) ///
			text(26 	8 "Profits Tax", 	size(small) color(blue)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(0(5)30, format(%12.0fc) labsize(medium)) ytitle("Effective Tax Rate (%)", size(medlarge)) xsc(r(0 30)) 			
			graph export "$figures/Figure_3_A.png", replace width(1200) height(1000)
}
restore

/* -------------------------- */
/* Income Level & Composition */
/* -------------------------- */

/* Income Shares Out of Total Income */
preserve
	keep if year == 2019
	drop if groups_position_merged_und == .
	
	global inc aux_reported_dividends aux_reported_interests aux_reported_rental final_wage final_mixed final_corp_income
	
	replace final_mixed=0 if final_mixed==.
	
	foreach var of varlist $inc {
		gen sh_`var'=`var'/total_final_und*100
	}

	
	gcollapse (mean) sh_* aux_reported_dividends aux_reported_interests aux_reported_rental final_wage final_mixed final_corp_income total_final_und, by(groups_position_merged_und)  

	gsort  -groups_position_merged_und
	gen n = _n
	
	insobs 1, before(15)
	insobs 1, before(25)
	
	drop n
	gen n=_n
	
	/* Income Share - Line graph */
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter sh_aux_reported_dividends 		n,cmissing(n)  mc(red%75) 		msize(small) c(l) lc(red%50)) ///
			(scatter sh_aux_reported_interests 		n, cmissing(n) mc(green%75) 	msize(small) c(l) lc(green%50)) ///
			(scatter sh_aux_reported_rental 		n, cmissing(n) mc(purple%75) 	msize(small) c(l) lc(purple%50)) ///
			(scatter sh_final_wage 					n, cmissing(n) mc(orange%75) 	msize(small) c(l) lc(orange%50)) ///
			(scatter sh_final_mixed 				n, cmissing(n) mc(sand%75) 		msize(small) c(l) lc(sand%50)) ///
			(scatter sh_final_corp_income 			n, cmissing(n) mc(blue%75) 		msize(small) c(l) lc(blue%50)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			text(99  20 	"Interests", 					size(small) color(green)) ///
			text(90  20 	"Rental", 						size(small) color(purple)) ///
			text(81  20 	"Wage", 						size(small) color(orange)) ///
			text(72  20 	"Mixed", 						size(small) color(sand)) ///
			text(99  30 	"Undistributed", 				size(small) color(blue)) ///
			text(90  30 	"Corporate Profits", 			size(small) color(blue)) ///
			text(63  20		"Dividends", 					size(small) color(red)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(, format(%12.0fc) labsize(medium)) ytitle("Share of Total Income (%)", size(medlarge)) 			
			graph export "$figures/Figure_1_B.png", replace width(1200) height(1000)
				
	/* Income Level */
	foreach var of varlist $inc total_final_und {
		gen t_`var'=`var'/1000
	}
	
	/* Using log-scale */
	foreach var of varlist $inc total_final_und {
		gen logscale_`var'=t_`var'+1
	}
			
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter logscale_total_final_und 			n, cmissing(n) mc(blue%75) 		msize(small) c(l) lc(blue%50)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			legend(off) graphregion(fcolor(white) lcolor(gs16)) xtitle("") yscale(log titlegap(2) range(296 250000)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(20 200 2000 200000, format(%12.0fc) labsize(medium) glp(dash) glw(vthin)) ytitle("Income Level (000s)", size(medlarge)) 
			graph export "$figures/Figure_1_A.png", replace width(1200) height(1000)
restore

/* ----------------------- */
/* Profile of shareholders */
/* ----------------------- */
preserve
	keep if year == 2019
	drop if groups_position_merged_und == .
	
	gen ind=1
	
	gcollapse (median)  ncorps_large_median = number_corps_largeshare ncorps_median = number_corps (mean) ncorps_large_avg = number_corps_largeshare ncorps_avg = number_corps ///
						large_shareholder large_share_firm profit_losses exempt_any share_profits_exempt (sum) ind, by(year groups_position_merged_und)  
						
	
	label var ncorps_large_median 		"Median number of firms of which individuals are large shareholders"
	label var ncorps_median 			"Median number of firms of which individuals are shareholders"
	label var ncorps_large_avg 			"Mean number of firms of which individuals are large shareholders"
	label var ncorps_avg 				"Mean number of firms of which individuals are shareholders"
	label var large_shareholder 		"Share of individuals that are large shareholders of at least one firm (%)"
	label var large_share_firm 			"Share of individuals that are large shareholders of at least one large firm (%)"
	label var profit_losses 			"Share of individuals that are shareholders of at least one firm with negative profits (%)"
	label var exempt_any 				"Share of individuals that are shareholders of at least one firm with exempted income (%)" 
	label var share_profits_exempt 		"Mean share of undistributed exempted profits"
	label var ind						"Number of individuals"
	
	replace large_shareholder = 100*large_shareholder
	replace large_share_firm = 100*large_share_firm
	
	gsort year -groups_position_merged_und
	by year: gen n = _n
	
	insobs 1, before(15)
	insobs 1, before(25)
	
	replace year=year[_n-1] if year==.
	
	drop n
	gen n=_n
	
	/* Share of individuals that are significant shareholders of (any) corporations and top corporations */
	local date: di %tdYYNNDD date(c(current_date), "DMY")	
	twoway 	(scatter large_shareholder n, mc(blue%60) cmissing(n) msize(small) c(l) lc(blue%40)) ///
		    (scatter large_share_firm n, mc(dkgreen%60) cmissing(n) msize(small) c(l) lc(dkgreen%40)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(, format(%12.0fc) labsize(medium)) ytitle("Share of Individuals", size(medlarge)) ///
 			text(85 8 "Shareholder", size(small) color(blue)) ///
			text(80 8 "(any corporation)", size(small) color(blue)) ///
			text(65 8 "Shareholder", size(small) color(dkgreen)) ///
			text(60 8 "(top decile corporation)", size(small) color(dkgreen)) 
			graph export "$figures/Figure_5_A.png", replace width(1200) height(1000)
	
	/* Number of firms in which individuals are shareholders (mean and median) */	
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter ncorps_large_avg n, mc(blue%60) cmissing(n) msize(small) c(l) lc(blue%40)) ///
			(scatter ncorps_large_median n, mc(dkgreen%60) cmissing(n) msize(small) c(l) lc(dkgreen%40)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(0(2)10, format(%12.0fc) labsize(medium)) ytitle("Number of Firms", size(medlarge)) ///
 			text(5.5 33 "Mean", size(small) color(blue)) ///
			text(1.2 33 "Median", size(small) color(dkgreen)) 
			graph export "$figures/Figure_5_B.png", replace width(1200) height(1000)
	
	/* Mean share of individuals that are shareholders of at least one firm with exempted income & mean share of undistributed exempted profits */
	local date: di %tdYYNNDD date(c(current_date), "DMY")
	twoway 	(scatter exempt_any n, mc(blue%60) cmissing(n) msize(small) c(l) lc(blue%40)) ///
			(scatter share_profits_exempt n, mc(dkgreen%60) cmissing(n) msize(small) c(l) lc(dkgreen%40)), ///
			xlabel(1 "Top [1.5%,1.4%]" 6 "Top [1%,0.9%]" 16 "Top [0.1%,0.09%]" 26 "Top [0.01%,0.009%]" 35 "Top 0.001%", angle(90) labsize(medium)) ///
			graphregion(fcolor(white) lcolor(gs16)) legend(off) xtitle("") yscale(titlegap(2)) xline(15 25, lc(black%5) lw(vvthick)) ///
			ylab(, format(%12.1fc) labsize(medium)) ytitle("Share of Individuals/Profits", size(medlarge)) ///
 			text(.65 30 "Shareholders of", size(small) color(blue)) ///
			text(.60 30 "Exempted Firms", size(small) color(blue)) ///
			text(.01 30 "Exempted Profits", size(small) color(dkgreen)) 
	graph export "$figures/Figure_5_C.png", replace width(1200) height(1000)
	
restore
